from myAI.adapters.tts import google as gTTS
from myAI.adapters.stt import google as gSTT
from myAI.adapters.tts import festival
import unittest

class TestGoogleSpeech(unittest.TestCase):
	"""
	Tests if Google can correctly turn text-to-speech-to-text
	"""

	def setUp(self):
		self.tts = gTTS.tts()
		self.stt = gSTT.stt()

	def test_hello_world(self):
		text = 'hello world'
		audio = self.tts.process(text, 'stdout')
		audio = self.stt.convert(audio)
		result = self.stt.process(audio)

		self.assertEqual(text, result)

	def test_invalid_language(self):
		self.assertRaises(Exception, lambda: gTTS.tts('mumbo-jumbo'))
		self.assertRaises(Exception, lambda: gSTT.stt('mumbo-jumbo'))

	def test_no_text(self):
		self.assertFalse(self.tts.process(''))
		self.assertFalse(self.stt.process(''))

class TestFestival(unittest.TestCase):
	"""
	Tests if Festival can correctly turn text-to-speech
	"""

	def setUp(self):
		self.tts = festival.tts()

	def test_hello_world(self):
		text = 'hello world'
		audio = self.tts.process(text, 'stdout')

		self.assertNotEqual('', audio)

	def test_invalid_language(self):
		self.assertRaises(Exception, lambda: festival.tts('mumbo-jumbo'))

	def test_no_text(self):
		self.assertFalse(self.tts.process(''))

if __name__ == "__main__":
	unittest.main()



from setuptools import setup

def format(input, start = 0):
	result = ''
	indent = False
	count = 0

	with open(input, 'r') as file:
		for line in file:
			if count > start:
				if line[:1] == '\t' and not indent:
					indent = True
					result += '::\n\n'

				if line[:1].isalnum() and indent:
					indent = False

				result += line.replace('> ', '\t')
			count += 1

	return result

blurb = 'An artificial intelligence written in Python\n'
ld = blurb + format('README.md', 3)
print(ld, end='\n\n')

setup(
	name = 'myAI',
	version = '0.2.0',
	author = 'Justin Willis',
	author_email = 'sirJustin.Willis@gmail.com',
	packages = ['myAI',],
	url = 'https://bitbucket.org/bkvaluemeal/myai',
	license = 'ISC License',
	description = 'An artificial intelligence written in Python',
	long_description = ld,
	install_requires = [
		'nltk >= 3.1',
		'requests >= 2.9.1'
	],
)



import importlib
import logging

logging.getLogger('requests').setLevel(logging.WARNING)
logging.basicConfig(
	level = logging.DEBUG,
	format = '[%(asctime)s] [%(levelname)s] [%(name)s]: %(message)s',
	datefmt = '%Y-%m-%d %H:%M:%S'
)

class Bot(object):
	"""
	The parent of all AI bots containing basic functions to interact

	Args:
		name (str): The name of the AI
		lang (str): The language to speak
	"""

	def __init__(self, name, lang = 'en-us', **kwargs):
		self.name = name
		self.logger = logging.getLogger('myAI')
		self.logger.info('Initializing %s' % (name))

	def talk(self):
		"""
		A sequence to collect an input and return a response
		"""

		return self.get_response(self.get_input())

	def get_input(self, input = None):
		"""
		Return the processed input

		Args:
			input (bin): Optional binary audio to process
		"""

		return self.stt.process(input)

	def get_response(self, input = None):
		"""
		Return the AI's response based on the input

		Args:
			input (str): The input statement to the bot
		"""

		return self.tts.process(input)

class BasicBot(Bot):
	"""
	A basic AI with a speech adapter

	Args:
		name (str): The name of the AI
		lang (str): The language to speak
	"""

	def __init__(self, name, lang = 'en-us', **kwargs):
		super().__init__(name, lang, **kwargs)

		self.tts = importlib.import_module(
			kwargs.get(
				'stt',
				'myAI.adapters.tts.google'
			)
		).tts(lang)

		self.stt = importlib.import_module(
			kwargs.get(
				'stt',
				'myAI.adapters.stt.google'
			)
		).stt(lang)

class LocalBot(Bot):
	"""
	A local AI with a speech adapter

	Args:
		name (str): The name of the AI
		lang (str): The language to speak
	"""

	def __init__(self, name, lang = 'en-us', **kwargs):
		super().__init__(name, lang, **kwargs)

		self.tts = importlib.import_module(
			kwargs.get(
				'tts',
				'myAI.adapters.tts.festival'
			)
		).tts(lang)

	def get_input(self):
		"""
		Return the processed input
		"""

		self.logger.warn('Local speech-to-text has not yet been implemented')
		return input('Input: ')
